﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace GridAddRowBug
{
    class CustomCreationFilter : IUIElementCreationFilter
    {
        private Rectangle elRect = Rectangle.Empty;

        public Rectangle ElRect
        {
            get { return elRect; }
            set { elRect = value; }
        }

        public void AfterCreateChildElements(UIElement parent)
        {
            if (parent is EditorWithTextUIElement && elRect != Rectangle.Empty)
            {
                parent.Rect = elRect;
            }

            if (parent is CellUIElement)
            {
                var cell = parent.GetContext(typeof(UltraGridCell)) as UltraGridCell;

                if (cell == null)
                    return;

                if (cell.IsInEditMode && elRect == Rectangle.Empty)
                {
                    AdjustTextboxPosition(cell, (CellUIElement)parent);
                }
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }

        private void AdjustTextboxPosition(UltraGridCell editCell, CellUIElement cellElement)
        {
            //var editCell = ultraGrid1.ActiveCell;

            // We won't do anything if the cell is not multiline or the AutoSizeEdit is set to False
            if (editCell.Column.CellMultiLine == DefaultableBoolean.False ||
                editCell.Column.AutoSizeEdit == DefaultableBoolean.False)
                return;

            // Get the TextBox.
            var textEditor = editCell.EditorResolved as EditorWithText;

            if (textEditor == null)
                return;

            var textBox = textEditor.TextBox as System.Windows.Forms.TextBox;

            // Check if right aligning with the cell is necessary
            // 1. The textbox goes outside of the grid
            // 2. The textbox is smaller that the grid
            if (textBox.Bounds.Right < editCell.Column.Layout.Grid.Right ||
                textBox.Width > editCell.Column.Layout.Grid.Width)
                return;

            // Right align the textbox
            int newX = cellElement.Rect.Right - textBox.Width > 0 ? cellElement.Rect.Right - textBox.Width : 0;
            int newY = cellElement.Rect.Top;

            textBox.Location = new Point(newX, newY);
            elRect = new Rectangle(newX, newY, 400, 100);
        }

    }
}
